@@ -184,6 +184,8 @@ class Field:
                     'type': 'any_of',
                     'types': [sf.type_schema(by_alias) for sf in self.sub_fields]
                 }
+        elif self.type_ is Any:
+            return 'any'
         elif issubclass(self.type_, Enum):
             choice_names = self._schema.choice_names or {}
             return {
